import sys
import os
import re
import unittest

import psycopg2

import tempus
from tempus import Cost, Request
from datetime import datetime

g_db_options = os.getenv('TEMPUS_DB_OPTIONS', 'dbname=tempus_test_db')

def road_node_id_from_coordinates(cur, pt_xy):
    cur.execute("select tempus.road_node_id_from_coordinates(%s,%s)", pt_xy)
    return cur.fetchone()[0]

if __name__ == '__main__':

    # initialize the tempus library (mandatory)
    tempus.init()

    # load a routing plugin
    plugin = tempus.load_plugin({'db/options': g_db_options}, plugin_name="isochrone_plugin")

    # keep a connection to the db
    conn = psycopg2.connect(g_db_options)
    cursor = conn.cursor()


    m = {}

    # call the plugin
    limit = 20.0
    results = tempus.request(plugin,
                             origin = road_node_id_from_coordinates(cursor, (-1.54427674939367, 47.2010310270336)),
                             steps = [ Request.Step(constraint = Request.TimeConstraint(
                                 type = Request.TimeConstraintType.ConstraintAfter,
                                 date_time = datetime(2016,10,21,6,43))) ],
                             plugin_options = { 'Isochrone/limit' : limit },
                             criteria = [Cost.Duration],
                             # pedestrian + TRAM
                             allowed_transport_modes = [1, 5])

    # explore the resulting isochrone
    for v in results[0].isochrone():
        if (v.x, v.y) in m:
            m[(v.x, v.y)].append((v.cost, v.mode))
        else:
            m[(v.x, v.y)] = [(v.cost, v.mode)]
    
    for k, v in m.items():
        print(k, v)



